pub struct MultivariateRing<F: FieldExtension, M: Positive, Form> { /* private fields */ }Expand description
An element P(X_0, ..., X_{N-1}) of the multivariate polynomial ring with N variables.
The polynomial can be either in coefficient or in evaluation form, given by Form
parameter. The number of coefficients/evaluations is M = 2 ^ N.
In coefficient representation data are the coefficients of the polynomial:
\sum_{i=0..2^N-1} c_i * \Prod_{j=0..N-1} X_j ^ bin(i)_j
bin(i) is the binary-decomposition of i (LSB first).
For example for N=2 the 2-variate polynomial is c_0 + c_1 . X_0 + c_2 . X_1 + c_3 . X_0 . X_1 and data = [c_0, c_1, c_2, c_3].
In evaluation representation data are the evaluations:
e_i = P(bin_signed(i))
bin_signed(i) is the signed binary-decomposition of i (LSB first).
For example for N=2 the evaluations are:
- e_0 = P(-1, -1)
- e_1 = P(-1, 1)
- e_2 = P( 1, -1)
- e_3 = P( 1, 1)
and data = [e_0, e_1, e_2, e_3]
Implementations
Sourceimpl<F: FieldExtension, M: Positive + PowerOfTwo, Form> MultivariateRing<F, M, Form>
impl<F: FieldExtension, M: Positive + PowerOfTwo, Form> MultivariateRing<F, M, Form>
pub fn new(data: SubfieldElements<F, M>) -> Self
pub fn random(rng: impl CryptoRngCore) -> Self
pub fn data(&self) -> &SubfieldElements<F, M>
pub fn into_data(self) -> SubfieldElements<F, M>
Sourceimpl<F: FieldExtension, M: Positive + PowerOfTwo> MultivariateRing<F, M, Coefficient>
impl<F: FieldExtension, M: Positive + PowerOfTwo> MultivariateRing<F, M, Coefficient>
Sourcepub fn to_eval_repr(self) -> MultivariateRing<F, M, Evaluation>
pub fn to_eval_repr(self) -> MultivariateRing<F, M, Evaluation>
Transform polynomial from coefficient representation to evaluation representation using the Walsh-Hadamard transform.
pub fn nb_coefs(&self) -> usize
Sourceimpl<F: FieldExtension, M: Positive + PowerOfTwo> MultivariateRing<F, M, Evaluation>
impl<F: FieldExtension, M: Positive + PowerOfTwo> MultivariateRing<F, M, Evaluation>
pub fn new_from_sparse_coef( coefs: impl IntoIterator<Item = (usize, SubfieldElement<F>)>, ) -> Self
pub fn from_coeffs(coefs: SubfieldElements<F, M>) -> Self
pub fn square(&self) -> Self
pub fn nb_evals(&self) -> usize