Complementary

Struct Complementary 

pub struct Complementary { /* private fields */ }
The complementary colors are the colors which are directly opposite from one another on the color wheel.

Complementary colors are contrasting and stand out against each other. Often it is a good idea to use a complementary color as the highlight color, as described above.

Implementations

Source

impl Complementary

pub fn new(primary: Color) -> Self

Generate Complementary scheme with your color

pub fn num_of_colors(&self) -> usize

Retrieve count colors of scheme

pub fn get_color(&self, index: usize) -> Option<Color>

Set color by index

pub fn primary_color(&self) -> Color

Retrieve primary color of scheme

pub fn set_primary_color(&mut self, val: Color)

Set the primary color of scheme