Compound

Struct Compound 

pub struct Compound { /* private fields */ }
Compound schemes (aka Split Complementary) are almost the same as complementary schemes.

Instead of using colors that are opposites, it uses colors on both sides of the opposite hue

Implementations

Source

impl Compound

pub fn new(primary: Color) -> Self

Generate Compound scheme with your color

pub fn num_of_colors(&self) -> usize

Retrieve count colors of scheme

pub fn get_color(&self, index: usize) -> Option<Color>

Set color by index

pub fn primary_color(&self) -> Color

Retrieve primary color of scheme

pub fn set_primary_color(&mut self, val: Color)

Set the primary color of scheme