pub struct SplitComplementary { /* private fields */ }Expand description
Split complementary is a color and the analogous colors to its complement color.
Using split complementary colors can give you a design with a high degree of contrast, yet still not as extreme as a real complementary color. It also results in greater harmony than the use of the direct complementary.
Implementations
Sourceimpl SplitComplementary
impl SplitComplementary
Sourcepub fn num_of_colors(&self) -> usize
pub fn num_of_colors(&self) -> usize
Retrieve count colors of scheme
Sourcepub fn primary_color(&self) -> Color
pub fn primary_color(&self) -> Color
Retrieve primary color of scheme
Sourcepub fn set_primary_color(&mut self, val: Color)
pub fn set_primary_color(&mut self, val: Color)
Set the primary color of scheme