FullScreen

Enum FullScreen 

pub enum FullScreen {
    Disabled,
    NoScale,
    ScaleAspectRatioIgnore,
    ScaleAspectRatioPreserve,
    ScaleNearestMultiple,
    Custom {
        value: f32,
    },
}
Representing possible full screen modes.

Can be extended with Custom by using concrete project values.

Variants



Disabled

FullScreen mode is not available.



NoScale

Preserves original pixel size.



ScaleAspectRatioIgnore

Scale without preserving aspect ratio - some distortion may occur, including non linear pixel sizes.



ScaleAspectRatioPreserve

Scale without aspect ratio distortion. Non linear pixel sizes may occur.



ScaleNearestMultiple

Scale without distortion, and doubling pixels (2x2, 4x4 etc) to nearest multiple to preserve pixel sizes.



Custom

Allows Scale to be extended (e.g. for using project specific scale modes).

Fields

value: f32

Scale value