OverlayProcess

Trait OverlayProcess 

pub trait OverlayProcess:
    Overlay
    + Process
    + Viewable { }
The OverlayProcess should be implemented by objects representing an operating Overlay.

These extra interface requirements are required for internal workings, but are not exposed via the minimal Overlay interface.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors