pub type FieldKeys<F, M> = PairwiseAuthKey<FieldElement<F>, FieldElements<F, M>>;Expand description
PairwiseAuthKey for a batch of M field values sharing a single global key.
See also FieldKey<F> for the single-value variant.
α and β₁…βₘ, such that MAC(xₜ) = α · xₜ + βₜ
Aliased Type
#[repr(C)]pub struct FieldKeys<F, M> {
pub alpha: Arc<FieldElement<F>>,
pub beta: HeapArray<FieldElement<F>, M>,
}Fields
alpha: Arc<FieldElement<F>>beta: HeapArray<FieldElement<F>, M>Trait Implementations
Sourceimpl<'a, F: FieldExtension, M: Positive> IntoIterator for &'a FieldKeys<F, M>
impl<'a, F: FieldExtension, M: Positive> IntoIterator for &'a FieldKeys<F, M>
Sourceimpl<F: FieldExtension, M: Positive> IntoIterator for FieldKeys<F, M>
impl<F: FieldExtension, M: Positive> IntoIterator for FieldKeys<F, M>
Sourcetype Item = PairwiseAuthKey<FieldElement<F>, FieldElement<F>>
type Item = PairwiseAuthKey<FieldElement<F>, FieldElement<F>>
The type of the elements being iterated over.
Sourcetype IntoIter = FieldShareKeysIterator<F, M>
type IntoIter = FieldShareKeysIterator<F, M>
Which kind of iterator are we turning this into?