Module open_share

Module open_share 

Structs

PairwiseAuthOpenShare
Generic opening of a [PairwiseAuthShare]: the value and the corresponding MAC, shared towards a remote peer for verification.

Type Aliases

OpenBaseFieldShare
Opening of a single authenticated share of a base field element (BaseField<C>).
OpenBaseFieldShares
Opening of a batch of authenticated base field shares. See PairwiseAuthOpenShare.
OpenBitShare
Opening of a single authenticated share of a GF(2^128) bit.
OpenFieldShare
Opening of a single authenticated field share. Alias for PairwiseAuthOpenShare<SubfieldElement<F>, FieldElement<F>>.
OpenFieldShares
Opening of a batch of M authenticated field shares. Alias for PairwiseAuthOpenShare<SubfieldElements<F,M>, FieldElements<F,M>>.
OpenPointShare
Opening of a single authenticated curve-point share. Alias for PairwiseAuthOpenShare<Point<C>, Point<C>>.
OpenPointShares
Opening of a batch of M authenticated curve-point shares. Alias for PairwiseAuthOpenShare<CurvePoints<C,M>, CurvePoints<C,M>>.
OpenScalarShare
Opening of a single authenticated share of a scalar field element (ScalarField<C>).
OpenScalarShares
Opening of a batch of authenticated scalar field shares. See PairwiseAuthOpenShare.