PointShares

Type Alias PointShares 

pub type PointShares<C, M> = PairwiseAuthShare<CurvePoints<C, M>, ScalarAsExtension<C>, CurvePoints<C, M>>;
A share of a batch of M curve points, with its associated MACs and the keys for all other parties’ shares.

A vectorised counterpart of PointShare<C>: same MAC/key structure, but all slots are stored as fixed-length HeapArrays of size M.

Alias for PairwiseAuthShare<CurvePoints<C,M>, ScalarAsExtension<C>, CurvePoints<C,M>>. See also PointShare<C> for the single-value variant.

Aliased Type

pub struct PointShares<C, M> { /* private fields */ }