PairwiseAuthenticated

Trait PairwiseAuthenticated 

pub trait PairwiseAuthenticated: RandomWith<Vec<Self::GlobalAuthKey>> {
    type GlobalAuthKey: Random + Clone + Any;

    // Required method
    fn get_global_keys(
        &self,
    ) -> impl ExactSizeIterator<Item = Self::GlobalAuthKey>;

    // Provided method
    fn deal_global_keys(
        n_parties: usize,
        seed: Seed,
        compatibility: bool,
    ) -> Vec<Vec<Self::GlobalAuthKey>> { ... }
}
A trait for secret shares that hold keys for pairwise authentication.

Required Associated Types

type GlobalAuthKey: Random + Clone + Any

Global keys used to authenticate the shares of all other parties.

Required Methods

fn get_global_keys(&self) -> impl ExactSizeIterator<Item = Self::GlobalAuthKey>

Get the global keys used to authenticate the shares of every other party.

Provided Methods

fn deal_global_keys( n_parties: usize, seed: Seed, compatibility: bool, ) -> Vec<Vec<Self::GlobalAuthKey>>

Deal global keys used to authenticate the shares of all parties.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors