Module types

Module types 

Re-exports

pub use heap_array::HeapArray;
pub use heap_array::HeapMatrix;
pub use heap_array::RowMajorHeapMatrix;
pub use identifiers::FaultyPeer;
pub use identifiers::PeerId;
pub use identifiers::PeerIndex;
pub use identifiers::PeerNumber;
pub use identifiers::ProtocolInfo;
pub use identifiers::SessionId;

Modules

heap_array
identifiers

Traits

Batched
A trait to define batching types that contain a compile-time known size of elements.
CollectAll
Collect an iterator of Results<T, E> into a container of T and a vector of E, then pack all the errors in a single error of the same type. Requires that E can be constructed from a Vec.
ConditionallySelectable
A type which can be conditionally selected with a loose promise of constant time. Compared to subtle::ConditionallySelectable, this trait does not require Copy, but the internal elements should be Copy for the promise to loosely hold.
Element
Marker trait for scalar element types used in broadcast arithmetic on HeapArray.
NonNegative
A trait to represent nonnegative (zero or positive) unsigned integer typenum constants.
Positive
A trait to represent positive nonzero unsigned integer typenum constants.
PositivePlusOne
A trait to represent positive nonzero unsigned integer typenum constants which accept “+1” operation.
TryFoldAll