Module heap_array

Module heap_array 

Re-exports

pub use array::HeapArray;
pub use array::HeapArrayTuple;
pub use matrix::HeapMatrix;
pub use matrix::RowMajorHeapMatrix;

Modules

array
matrix
ops

Type Aliases

CurvePoints
A batch of M curve points of type C::Point.
FieldElements
A batch of M field elements of type F.
Scalars
A batch of M scalar elements of type C::Scalar.
ScalarsAsExtension
A batch of M scalar elements of type C::ScalarAsExtension.
SubfieldElements
A batch of M subfield elements of type F.