pub type FieldElements<F, M> = HeapArray<FieldElement<F>, M>;Expand description
A batch of M field elements of type F.
Aliased Type
pub struct FieldElements<F, M> { /* private fields */ }pub type FieldElements<F, M> = HeapArray<FieldElement<F>, M>;A batch of M field elements of type F.
pub struct FieldElements<F, M> { /* private fields */ }