Batched

Trait Batched 

pub trait Batched:
    Sized
    + IntoExactSizeIterator<Item: Send>
    + FromIterator<Self::Item> {
    type Size: Positive;

    // Provided method
    fn batch_size() -> usize { ... }
}
A trait to define batching types that contain a compile-time known number of elements.

Required Associated Types

type Size: Positive

The size of the batch.

Provided Methods

fn batch_size() -> usize

Returns the size of the batch as a usize.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors

Source

impl<F: FieldExtension, M: Positive, Exp: PowPairExponent> Batched for PowPairs<F, M, Exp>

Source

type Size = M

Source

impl<F: FieldExtension, M: Positive> Batched for DaBits<F, M>

Source

type Size = M

Source

impl<F: FieldExtension, M: Positive> Batched for Singlets<F, M>

Source

type Size = M

Source

impl<F: FieldExtension, M: Positive> Batched for Triples<F, M>

Source

type Size = M

Source

impl<T: Sized + Send, M: Positive> Batched for HeapArray<T, M>

Source

type Size = M

Source

impl<V, A, B, M: Positive> Batched for BatchedShare<V, A, B, M>
where V: Send, B: Send, A: Clone + Send + Sync,

Source

type Size = M