Element

Trait Element 

pub trait Element { }
Marker trait for scalar element types used in broadcast arithmetic on HeapArray.

This trait is intentionally not implemented for HeapArray itself, which allows both element-wise (HeapArray * HeapArray) and broadcast (HeapArray * scalar) operator impls to coexist without coherence conflicts.

Blanket-implemented for all Copy types. Since HeapArray contains a Box<[T]>, it can never be Copy and therefore can never satisfy Element.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors

Source

impl<T: Copy> Element for T