Structs
- Take
Exact Iter - An iterator that takes exactly N elements from the underlying iterator.
Traits
- Into
Exact Size Iterator - A trait for types that can be converted into an
ExactSizeIteratorviainto_iter(). - Take
Exact - A trait for iterators that take exactly N elements, panicking if the iterator is shorter than N.