Crate dkg_core

Crate dkg_core 

DKG Core

The DKG is based on the Secure Distributed Key Generation for Discrete-Log Based Cryptosystems paper.

The implementation is a state machine which has Phases 0 to 3. Phase 3 is only reachable if any of the n parties does not publish its shares in the first phase. If less than t parties participate in any stage, the DKG fails.

Re-exports

pub use board::BoardPublisher;
pub use node::DKGNodeError;
pub use node::DKGPhase;
pub use node::Phase2Result;

Modules

board
Board trait and implementations for publishing data from each DKG phase
node
Higher level objects for running a JF-DKG
primitives
Low level primitives and datatypes for implementing DKGs

Functions

generate_keypair