Modules
- algebra
- assumptions
- ciphers
- commitments
- constants
- correlated_
randomness - errors
- hashing
- random
- sharing
- signing
- transcripts
- types
- utils
Macros
- chain_
eq - An adaptor for
itertools::chain!macro which creates an ExactSizeIterator. - izip_eq
- Create an iterator running multiple iterators in lockstep, panicking if they are not the same length.
- izip_
eq_ lazy - Create an iterator running multiple iterators in lockstep, panicking if they are not of the same length.
- par_
izip - Create a parallel iterator running multiple iterators in lockstep, panicking if they are not the same length.
- sync_
join - Macro that joins futures and ensures all have completed before any values are dropped.
- sync_
try_ join - Macro that try_joins futures and ensures all have completed before any values are dropped.
- zip_
maps - Create an iterator over hashmaps with the same keys. Accepts a list of keys, and the maps to be iterated over. Panics if any of the keys are not found in the maps.