pub struct Complementary { /* private fields */ }Expand description
The complementary colors are the colors which are directly opposite from one another on the color wheel.
Complementary colors are contrasting and stand out against each other. Often it is a good idea to use a complementary color as the highlight color, as described above.
Implementations
Sourceimpl Complementary
impl Complementary
Sourcepub fn num_of_colors(&self) -> usize
pub fn num_of_colors(&self) -> usize
Retrieve count colors of scheme
Sourcepub fn primary_color(&self) -> Color
pub fn primary_color(&self) -> Color
Retrieve primary color of scheme
Sourcepub fn set_primary_color(&mut self, val: Color)
pub fn set_primary_color(&mut self, val: Color)
Set the primary color of scheme