Operates a secret share with a public plaintext (addition/subtraction). These are often
asymmetric (e.g., only the first peer folds the constant into its share). Scaling a share by a
public constant is expressed directly through Mul where needed, so it is not part of this
trait.
Secret share bounds, allowing arithmetic operations and reconstruction. Sharing/inputting a
secret might requre communication and is thus deferred to the online phase.