Re-exports
pub use authenticated::*;
Modules
Traits
- Plaintext
Ops - A trait used to add a plaintext to a certain type. Commonly used to correct shares after a masked opening, or to add a public constant
- Reconstructible
- Reconstructs a secret-shared value from a collection of openings and a local share.