Module sharing

Module sharing 

Re-exports

pub use authenticated::*;

Modules

authenticated
unauthenticated

Traits

PlaintextOps
A trait used to add a plaintext to a certain type. Commonly used to correct shares after a masked opening, or to add a public constant
Reconstructible
Reconstructs a secret-shared value from a collection of openings and a local share.