PairwiseAuthKey

Struct PairwiseAuthKey 

#[repr(C)]
pub struct PairwiseAuthKey<A, B> { pub alpha: GlobalKey<A>, pub beta: B, }
Generic authenticated key: a global key alpha: A and a local key beta: B, satisfying MAC(x) = α · x + β.

This is the base type for both:

  • [FieldShareKey<F>] — single-value authenticated key
  • [FieldShareKeys<F,M>] — batched authenticated key (M values, shared α)

Fields

alpha: GlobalKey<A>beta: B

Implementations

Source

impl<A, B> PairwiseAuthKey<A, B>

pub fn new(alpha: Arc<A>, beta: B) -> Self

Create a new PairwiseAuthKey with the given global key alpha and local key beta.

pub fn get_beta(&self) -> &B

Return a reference to the local key beta.

pub fn get_alpha(&self) -> &A

Return a reference to the global key alpha.

pub fn alpha(&self) -> Arc<A>

Return the value of the global key alpha.

Source

impl<A: Clone, B: Copy, M: Positive> PairwiseAuthKey<A, HeapArray<B, M>>

Generic split and merge operations on any batched key PairwiseAuthKey<A, HeapArray<B, M>>. Covers both FieldShareKeys<F, M> and CurveKeys<C, M>.

pub fn split<M1, M2>( self, ) -> (PairwiseAuthKey<A, HeapArray<B, M1>>, PairwiseAuthKey<A, HeapArray<B, M2>>)
where M1: Positive, M2: Positive + Add<M1, Output = M>,

Split a batched key into two smaller batched keys with the same global key alpha and disjoint local keys beta (first M1 values in the first key, next M2 values in the second key).

pub fn split_halves<MDiv2>( self, ) -> (PairwiseAuthKey<A, HeapArray<B, MDiv2>>, PairwiseAuthKey<A, HeapArray<B, MDiv2>>)
where MDiv2: Positive + Mul<U2, Output = M>,

Split a batched key into two smaller batched keys with the same global key alpha and disjoint local keys beta (first M/2 values in the first key, next M/2 values in the second key).

pub fn merge_halves( this: Self, other: Self, ) -> PairwiseAuthKey<A, HeapArray<B, Prod<M, U2>>>
where M: Positive + Mul<U2, Output: Positive>, A: PartialEq,

Merge two batched keys with the same global key alpha and disjoint local keys beta (first M/2 values in the first key, next M/2 values in the second key) into a single batched key with M values in the local key.

pub fn split3<M1, M2, M3>( self, ) -> (PairwiseAuthKey<A, HeapArray<B, M1>>, PairwiseAuthKey<A, HeapArray<B, M2>>, PairwiseAuthKey<A, HeapArray<B, M3>>)
where M1: Positive, M2: Positive + Add<M1>, M3: Positive + Add<Sum<M2, M1>, Output = M>,

Split a batched key into three smaller batched keys with the same global key alpha and disjoint local keys beta (first M1 values in the first key, next M2 values in the second key, last M3 values in the third key).

pub fn split_thirds<MDiv3>( self, ) -> (PairwiseAuthKey<A, HeapArray<B, MDiv3>>, PairwiseAuthKey<A, HeapArray<B, MDiv3>>, PairwiseAuthKey<A, HeapArray<B, MDiv3>>)
where MDiv3: Positive + Mul<U3, Output = M>,

Split a batched key into three smaller batched keys with the same global key alpha and disjoint local keys beta (first M/3 values in the first key, next M/3 values in the second key, last M/3 values in the third key).

pub fn merge_thirds( first: Self, second: Self, third: Self, ) -> PairwiseAuthKey<A, HeapArray<B, Prod<M, U3>>>
where M: Positive + Mul<U3, Output: Positive>, A: PartialEq,

Merge three batched keys with the same global key alpha and disjoint local keys beta (first M/3 values in the first key, next M/3 values in the second key, last M/3 values in the third key) into a single batched key with M values in the local key.