pub struct PairwiseAuthShare<V, A, B> { /* private fields */ }Expand description
Generic base for pairwise authenticated shares, analogous to PairwiseAuthKey.
The three type parameters are:
V: value type.B: MAC and local key (Beta) type, an additive Group.A: global key (Alpha) type.
The authenticated shares fulfill this relation:
MAC(x_i)_j = α_ji · x_i + β_ji ∀i∈[1..n] ∀j∈[1..n]∖{i}
where β_ji and α_ji are the (local and global) keys of value x_i held by P_j.
As such, the share of party P_i contains:
x_i, the unauthenticated share value (s.t.x = Σ x_i){MAC(x_i)_j} ∀j∈[1..n]∖{i}, the MACs ofx_ifor each of the other n-1 parties.{β_ij} ∀j∈[1..n]∖{i}and{α_ij} ∀j∈[1..n]∖{i}, the (local and global) keys tied to the values&MACs of the other n-1 parties.
Implementations
Sourcepub fn try_new(
value: V,
macs: Box<[B]>,
keys: Box<[PairwiseAuthKey<A, B>]>,
) -> Result<Self, PrimitiveError>
pub fn try_new( value: V, macs: Box<[B]>, keys: Box<[PairwiseAuthKey<A, B>]>, ) -> Result<Self, PrimitiveError>
Constructs a new share, returning an error if the MAC and key slices are inconsistent (empty or length-mismatched).
Sourcepub fn get_value_mut(&mut self) -> &mut V
pub fn get_value_mut(&mut self) -> &mut V
Returns a mutable reference to the share value.
Sourcepub fn get_mac(&self, peer_index: PeerIndex) -> Option<&B>
pub fn get_mac(&self, peer_index: PeerIndex) -> Option<&B>
Returns the MAC for the given peer index, or None if out of bounds.
Sourcepub fn get_keys(&self) -> &[PairwiseAuthKey<A, B>]
pub fn get_keys(&self) -> &[PairwiseAuthKey<A, B>]
Returns a slice of all keys (one per distant peer).
Sourcepub fn get_keys_mut(&mut self) -> &mut [PairwiseAuthKey<A, B>]
pub fn get_keys_mut(&mut self) -> &mut [PairwiseAuthKey<A, B>]
Returns a mutable slice of all keys.
Sourcepub fn get_key(&self, peer_index: PeerIndex) -> Option<&PairwiseAuthKey<A, B>>
pub fn get_key(&self, peer_index: PeerIndex) -> Option<&PairwiseAuthKey<A, B>>
Returns the key for the given peer index, or None if out of bounds.
Sourcepub fn into_value(self) -> V
pub fn into_value(self) -> V
Consumes the share, returning the value.
Sourcepub fn into_inner(self) -> (V, Box<[B]>, Box<[PairwiseAuthKey<A, B>]>)
pub fn into_inner(self) -> (V, Box<[B]>, Box<[PairwiseAuthKey<A, B>]>)
Consumes the share, returning all the internal data (value, MACs, and keys).
Sourcepub fn n_distant_parties(&self) -> usize
pub fn n_distant_parties(&self) -> usize
Number of distant parties (excludes the local party).
Sourcepub fn get_alphas(&self) -> impl ExactSizeIterator<Item = GlobalKey<A>> + '_
pub fn get_alphas(&self) -> impl ExactSizeIterator<Item = GlobalKey<A>> + '_
Returns an iterator over the global keys (alpha values) for each distant peer.
Sourcepub fn get_betas(&self) -> impl ExactSizeIterator<Item = &B> + '_
pub fn get_betas(&self) -> impl ExactSizeIterator<Item = &B> + '_
Returns an iterator over the local keys (beta values) for each distant peer.
Sourcepub fn compute_mac(value: V, key: &PairwiseAuthKey<A, B>) -> B
pub fn compute_mac(value: V, key: &PairwiseAuthKey<A, B>) -> B
Compute the MAC of a value x for ( α-global, β-local) keys as:
MAC(x) = α * x + β
Sourcepub fn verify_mac(
key: &PairwiseAuthKey<A, B>,
opening: PairwiseAuthOpenShare<V, B>,
) -> Choice
pub fn verify_mac( key: &PairwiseAuthKey<A, B>, opening: PairwiseAuthOpenShare<V, B>, ) -> Choice
Verify the MAC of a value x for ( α-global, β-local) keys fulfills:
MAC(x) == α * x + β
Sourcepub fn split<M1, M2>(
self,
) -> (BatchedShare<V, A, B, M1>, BatchedShare<V, A, B, M2>)
pub fn split<M1, M2>( self, ) -> (BatchedShare<V, A, B, M1>, BatchedShare<V, A, B, M2>)
Splits a batched share of size M into two smaller batched shares (M1, M2), where M = M1 + M2.
Sourcepub fn split_halves<MDiv2>(
self,
) -> (BatchedShare<V, A, B, MDiv2>, BatchedShare<V, A, B, MDiv2>)
pub fn split_halves<MDiv2>( self, ) -> (BatchedShare<V, A, B, MDiv2>, BatchedShare<V, A, B, MDiv2>)
Splits a batched share of size M into two smaller batched shares (M1, M2), where M = M1 + M2.
Sourcepub fn merge_halves(
this: Self,
other: Self,
) -> BatchedShare<V, A, B, Prod<M, U2>>
pub fn merge_halves( this: Self, other: Self, ) -> BatchedShare<V, A, B, Prod<M, U2>>
Merges two batched shares of sizes M/2 into a larger batched share of size M.
Sourcepub fn split_thirds<MDiv3>(
self,
) -> (BatchedShare<V, A, B, MDiv3>, BatchedShare<V, A, B, MDiv3>, BatchedShare<V, A, B, MDiv3>)
pub fn split_thirds<MDiv3>( self, ) -> (BatchedShare<V, A, B, MDiv3>, BatchedShare<V, A, B, MDiv3>, BatchedShare<V, A, B, MDiv3>)
Splits a batched share of size M into three smaller batched shares (M1, M2, M3), where M = M1 + M2 + M3.
Sourcepub fn merge_thirds(
first: Self,
second: Self,
third: Self,
) -> BatchedShare<V, A, B, Prod<M, U3>>
pub fn merge_thirds( first: Self, second: Self, third: Self, ) -> BatchedShare<V, A, B, Prod<M, U3>>
Merges three batched shares of sizes M/3 into a larger batched share of size M.
Sourcepub fn chunks<CS: Positive>(
&self,
) -> BatchedSharesChunks<<HeapArray<V, M> as IntoIterator>::IntoIter, <HeapArray<B, M> as IntoIterator>::IntoIter, A, <HeapArray<B, M> as IntoIterator>::IntoIter, CS> ⓘwhere
M: PartialDiv<CS>,
pub fn chunks<CS: Positive>(
&self,
) -> BatchedSharesChunks<<HeapArray<V, M> as IntoIterator>::IntoIter, <HeapArray<B, M> as IntoIterator>::IntoIter, A, <HeapArray<B, M> as IntoIterator>::IntoIter, CS> ⓘwhere
M: PartialDiv<CS>,
Creates an iterator that yields fixed-size batched chunks of size CS.