pub trait Verifiable: Reconstructible {
// Required method
fn verify(&self, openings: Vec<Self::Opening>) -> Result<(), PrimitiveError>;
// Provided methods
fn verify_from(
&self,
_opening: Self::Opening,
_peer_index: PeerIndex,
) -> Result<(), PrimitiveError> { ... }
fn verify_all(shares: Vec<Self>) -> Result<(), PrimitiveError> { ... }
}Expand description
Verify secret share/s from one or more openings.
Required Methods
Provided Methods
Sourcefn verify_from(
&self,
_opening: Self::Opening,
_peer_index: PeerIndex,
) -> Result<(), PrimitiveError>
fn verify_from( &self, _opening: Self::Opening, _peer_index: PeerIndex, ) -> Result<(), PrimitiveError>
Verify an opening from a specific peer given your share and the opening. Only applicable to publicly verifiable or pairwise authenticated shares.
Sourcefn verify_all(shares: Vec<Self>) -> Result<(), PrimitiveError>
fn verify_all(shares: Vec<Self>) -> Result<(), PrimitiveError>
Verify all shares by opening each share towards all other peers and performing pairwise verification of the openings.
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".