pub trait PlaintextOps: Reconstructible + Clone {
// Required methods
fn add_plaintext(self, ptx: &Self::Value, is_first_peer: bool) -> Self;
fn sub_plaintext(self, ptx: &Self::Value, is_first_peer: bool) -> Self;
}Expand description
A trait used to add a plaintext to a certain type. Commonly used to correct shares after a masked opening, or to add a public constant
Required Methods
Sourcefn add_plaintext(self, ptx: &Self::Value, is_first_peer: bool) -> Self
fn add_plaintext(self, ptx: &Self::Value, is_first_peer: bool) -> Self
Add a plaintext to the share, consuming the share and returning a new one.
Sourcefn sub_plaintext(self, ptx: &Self::Value, is_first_peer: bool) -> Self
fn sub_plaintext(self, ptx: &Self::Value, is_first_peer: bool) -> Self
Subtract a plaintext from the share, consuming the share and returning a new one.
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.